@@ -23,19 +23,19 @@ example(hprabclust)
 example(piecewiselin)
 example(qkulczynski)
 example(regpop.sar)
-regpop.sar(x, p.nb=0.046)
+# regpop.sar(x, p.nb=0.046)
 example(toprab)
 example(prab.sarestimate)
-prab.sarestimate(x)
+# prab.sarestimate(x)
 example(specgroups)
 # example(abundtest)
 set.seed(1234)
 # This is done in example(specgroups):
 # x <- prabinit(prabmatrix=siskiyou, neighborhood=siskiyou.nb,
 #              distance="logkulczynski")
-a1 <- abundtest(x, times=3, p.nb=0.0465)
-a2 <- abundtest(x, times=3, p.nb=0.0465, teststat="groups",
-                groupvector=siskiyou.groups)
-summary(a1)
-summary(a2)
-build.nblist(x)
+# a1 <- abundtest(x, times=3, p.nb=0.0465)
+# a2 <- abundtest(x, times=3, p.nb=0.0465, teststat="groups",
+#                 groupvector=siskiyou.groups)
+# summary(a1)
+# summary(a2)
+# build.nblist(x)
